##
##  unixodbc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 2.3.12
%define       V_dist 2.3.12

#   package information
Name:         unixodbc
Summary:      Unix ODBC Toolkit
URL:          http://www.unixodbc.org/
Vendor:       Peter Harvey, Nick Gorham
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Database
License:      GPL
Version:      %{V_opkg}
Release:      20230810

#   list of sources
Source0:      ftp://ftp.unixodbc.org/pub/unixODBC/unixODBC-%{V_dist}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, flex, bison
PreReq:       OpenPKG, openpkg >= 20160101
Provides:     ODBC
Conflicts:    iodbc

%description
    UnixODBC is a full-featured ODBC solution for Unix.

%track
    prog unixodbc = {
        version   = %{V_dist}
        url       = http://www.unixodbc.org/download.html
        regex     = unixODBC-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n unixODBC-%{V_dist}

%build
    #   configure toolkit
    %{l_shtool} subst \
        -e 's;\(--mode=link $(CCLD)\);\1 -static;' \
        exe/Makefile.in
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --sysconfdir=%{l_prefix}/etc/unixodbc \
        --disable-gui \
        --disable-drivers \
        --enable-threads \
        --enable-static \
        --with-pic \
        --enable-shared \
        --without-pth

    #   build toolkit
    %{l_make} %{l_mflags -O}

%install
    #   install toolkit
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   strip down installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std} \
        '%config %{l_prefix}/etc/unixodbc/*.ini'

%files -f files

%clean

